;     SCASM macro for Flight Simulator

;     This macro adds falling snow in your scenery
;     Author: Luis Vieira de Sa <luis@it.uc.pt>
;     http://www.it.uc.pt/~luis/fltsim.html
;     March 1997

;     General usage (needs SCASM 1.7 or higher): 
;     macro( snow.scm  Lat  Lon  Range  Texture Complex=3 )
;                      1    2    3      4       5

;     With Airport & Scenery Designer you need to copy this
;     file to the SCASM macro's directory (or to your map files
;     output directory) and add the following data into the
;     'macro.txt' file (in a single line):
;     snow.scm 0104  Latitude  Longitude  Range(Km)=25
;     Texture=snow20.r8 Complexity=3

;     Remmember that snow appears when:

;          - there some wind!                   ... and
;          - season is winter!                  ... and
;          - texture ground flag is ON!

;     also do not forget to install the texture file!

Area( B  %1  %2  %3 )

; this tests for wind
IfVarAnd( :end C72 FFFF )

; this tests for texture ground flag
IfVarAnd( :end 340 FFFF )

; this tests for winter
IfVarRange( :end 6F8 0 0 )

; this tests the complexity
IfVarRange( :end 346 %5 4 )

PerspectiveCall( :start )
Jump( :end )

:start
Perspective
Dbx( 4C 00 fa ff 00 00 00 00 00 00 00 00 0a 00 e8 1b )
TransformCall( :draw_it 0 0 0 0 02a2 0 02a4 0 02a6 ) 
Return

:draw_it
Points( 0
	-20 	-12	20
	20	-12	20
	20	10	20
	-20	10	20
	)
Bitmap( %4 0 0 0 0 )
:phase_0
IfVarAnd( :phase_1 282 0x0001 )
Jump( :here )
:phase_1
IfVarAnd( :phase_2 282 0x0002 )
RepeatBitmap( 0 0 -8 )
Jump( :here )
:phase_2
IfVarAnd( :phase_3 282 0x0004 )
RepeatBitmap( 0 0 -16 )
Jump( :here )
:phase_3
IfVarAnd( :phase_4 282 0x0008 )
RepeatBitmap( 0 0 -24 )
Jump( :here )
:phase_4
IfVarAnd( :phase_5 282 0x0010 )
RepeatBitmap( 0 0 -32 )
Jump( :here )
:phase_5
IfVarAnd( :phase_6 282 0x0020 )
RepeatBitmap( 0 0 -40 )
Jump( :here )
:phase_6
IfVarAnd( :phase_7 282 0x0040 )
RepeatBitmap( 0 0 -48 )
Jump( :here )
:phase_7
IfVarAnd( :phase_8 282 0x0080 )
RepeatBitmap( 0 0 -56 )
Jump( :here )
:phase_8
IfVarAnd( :phase_9 282 0x0100 )
RepeatBitmap( 0 0 -64 )
Jump( :here )
:phase_9
IfVarAnd( :phase_a 282 0x0200 )
RepeatBitmap( 0 0 -72 )
Jump( :here )
:phase_a
IfVarAnd( :phase_b 282 0x0400 )
RepeatBitmap( 0 0 -80 )
Jump( :here )
:phase_b
IfVarAnd( :phase_c 282 0x0800 )
RepeatBitmap( 0 0 -88 )
Jump( :here )
:phase_c
IfVarAnd( :phase_d 282 0x1000 )
RepeatBitmap( 0 0 -96 )
Jump( :here )
:phase_d
IfVarAnd( :phase_e 282 0x2000 )
RepeatBitmap( 0 0 -104 )
Jump( :here )
:phase_e
IfVarAnd( :phase_f 282 0x4000 )
RepeatBitmap( 0 0 -112 )
Jump( :here )
:phase_f
RepeatBitmap( 0 0 -120 )

:here
BitMapMode( 1 )
TexPoly( 0 0 -32670 0
	0	0	1000
	1	1000	1000	
	2	1000	0
	3	0	0
	 )
BitMapMode( 0 )
Return
:end
EndA
